@@ -7,7 +7,7 @@ require Exporter;
 use parent 'Exporter';
 use OPCUA::Open62541::Constant;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 our @EXPORT_OK = @OPCUA::Open62541::Constant::EXPORT_OK;
 our %EXPORT_TAGS = %OPCUA::Open62541::Constant::EXPORT_TAGS;
@@ -371,6 +371,12 @@ If set to false, historical data can be deleted (this is the default).
 
 =item $status_code = $client->connect_async($endpointUrl, $callback, $userdata)
 
+1.0 API
+
+=item $status_code = $client->connectAsync($endpointUrl)
+
+1.1 API
+
 =over 8
 
 =item $callback = sub { my ($client, $userdata, $requestId, $status_code) = @_ }
@@ -388,6 +394,14 @@ run_iterate() or open62541 may try to operate on a non existent socket.
 
 =item $client_state = $client->getState()
 
+1.0 API
+
+=item ($channel_state, $session_state, $connect_status) = $client->getState()
+
+1.1 API
+
+In scalar context return 1.0 API compatible $client_state.
+
 =item $status_code = $client->sendAsyncBrowseRequest(\%request, \&callback, $data, \$reqId)
 
 =over 8
